@@ -198,7 +198,7 @@ def psets_prep(psets):
     return psets
 
 
-def map_prep(psets, name, system_kwargs, chdir, out_subdirs, keep_results=True, progress_dt=None, **kwargs):
+def map_prep(psets, name, system_kwargs, chdir, out_subdirs, keep_results=True, progress_dt=None, raise_in_wrapper=None):
     verbose = system_kwargs['verbose']
     vstats = system_kwargs['vstats']
 
@@ -220,8 +220,8 @@ def map_prep(psets, name, system_kwargs, chdir, out_subdirs, keep_results=True,
         system_kwargs['out_subdirs'] = out_subdirs
     if name:
         system_kwargs['name'] = name
-    if 'raise_in_wrapper' in kwargs:
-        system_kwargs['raise_in_wrapper'] = kwargs['raise_in_wrapper']
+    if raise_in_wrapper:
+        system_kwargs['raise_in_wrapper'] = raise_in_wrapper
 
     system_kwargs['pset_ids'] = {}
 
@@ -321,7 +321,10 @@ def handle_return_common(out_func, ret, system_stats, system_kwargs, user_kwargs
 
             if 'traceback' in user_ret:
                 system_kwargs['pset_ids'][pset_id]['_traceback'] = user_ret['traceback']
-                pslogger.log('traceback:\n' + user_ret['traceback'], stderr=verbose > 1)
+                verbose_t = verbose > 1
+                pslogger.log('traceback:\n' + user_ret['traceback'], stderr=verbose_t)
+                if verbose > 0 and not verbose_t:
+                    print('(traceback is in', pslogger.logger_filename+')', file=sys.stderr)
         else:
             del system_kwargs['pset_ids'][pset_id]
             user_ret['pset'].pop('_pset_id', None)
@@ -383,7 +386,7 @@ def resolve_kwargs(global_kwargs, kwargs, backend, backends):
         if k in global_kwargs:
             gkw = global_kwargs[k]
             if gkw.get('strong'):
-                pslogger.log('environment variable overrides passed in value for', k, verbose > 0)
+                pslogger.log('environment variable overrides passed in value for '+k, verbose > 0)
                 system_kwargs[k] = gkw['value']
             else:
                 system_kwargs[k] = kwargs[k]
@@ -393,19 +396,14 @@ def resolve_kwargs(global_kwargs, kwargs, backend, backends):
         if k not in system_kwargs:
             system_kwargs[k] = global_kwargs[k]['value']
 
-    backend_prefixes = tuple(x+'_' for x in backends.keys())
-    kept_other_kwargs = {}
-    for k in other_kwargs:
-        if k.startswith(backend_prefixes):
-            if k.startswith(backend+'_'):
-                k2 = k.replace(backend+'_', '', 1)
-                kept_other_kwargs[k2] = other_kwargs[k]
-            else:
-                pslogger.log('discarding kwarg due to our backend choice: ', k, other_kwargs[k], stderr=verbose > 1)
-        else:
-            kept_other_kwargs[k] = other_kwargs[k]
+    backend_kwargs = other_kwargs.pop(backend, {})
 
-    return system_kwargs, kept_other_kwargs
+    for b in backends:
+        if b in other_kwargs:
+            pslogger.log('discarding kwarg {} due to our backend choice'.format(b), stderr=verbose > 1)
+            other_kwargs.pop(b)
+
+    return system_kwargs, backend_kwargs, other_kwargs
 
 
 def make_subdir_name(count, prefix='ps'):
