@@ -18,6 +18,12 @@ def test__coerce_to_category():
     s2 = paramsurvey.params._coerce_to_category(s1)
     assert s2.dtype == 'category'
 
+    s1 = pd.Series([[0]] * 10)  # unhashable type
+    s2 = paramsurvey.params._infer_category(s1)
+    assert s1.equals(s2)
+    #assert s2.dtype != 'category'  # can't do this thanks to pandas
+    assert s2.dtype == 'object'
+
 
 def test__infer_category():
     s1 = pd.Series(range(10))
@@ -31,6 +37,8 @@ def test__infer_category():
     s1 = pd.Series([[0]] * 1000)  # unhashable type
     s2 = paramsurvey.params._infer_category(s1)
     assert s1.equals(s2)
+    #assert s2.dtype != 'category'  # can't do this thanks to pandas
+    assert s2.dtype == 'object'
 
     s1 = pd.Series([0] * 1000)
     s2 = paramsurvey.params._infer_category(s1)
@@ -65,6 +73,7 @@ def test_product():
 
     vi = sys.version_info
     if vi.major == 3 and vi.minor < 6:
+        # pre python 3.6 does not have ordered dicts by default
         df_dicts = paramsurvey.params.product(OrderedDict((('col1', [1, 2]), ('col2',  [3, 4]), ('col3', [5, 6]))))
     else:
         df_dicts = paramsurvey.params.product({'col1': [1, 2], 'col2': [3, 4], 'col3': [5, 6]})
@@ -90,6 +99,27 @@ def test_product():
     assert len(df_longer) == 16
     assert not df.equals(df_longer)
 
+    df3 = pd.DataFrame({'col3': [[5, 6], [7, 8]]})
+    df = paramsurvey.params.product(df1, df2, df3)
+    assert len(df) == 8
+    assert df['col3'].dtype == 'object', 'unhashable type inhibits category'
+
+    ps3 = pd.Series([5, 6], name='col3', dtype='category')
+    df = paramsurvey.params.product(df1, df2, ps3)
+    assert len(df) == 8
+    assert df['col3'].dtype == 'category', 'sending in a category works'
+
+    ps3 = pd.Series([5, 6], name='col3', dtype='category')
+    df = paramsurvey.params.product(df1, df2, ps3, infer_category=False)
+    assert len(df) == 8
+    assert df['col3'].dtype == 'category', 'category remains one'
+    with pytest.raises(TypeError):
+        assert df['col2'].dtype != 'category', 'not converted to a category'
+
+    ps3 = 3
+    with pytest.raises(ValueError):
+        df = paramsurvey.params.product(df1, df2, ps3)
+
 
 def test_add_column():
     df = paramsurvey.params.product({'col1': [1, 2]}, {'col2': [3, 4]}, {'col3': [5, 6]})
@@ -138,6 +168,7 @@ def test_param_stress():
     assert vmem1 - vmem0 < 1.055, 'tight limit that requires int16 type to pass'
 
     if 'TRAVIS_CPU_ARCH' in os.environ and os.environ['TRAVIS_CPU_ARCH'] == 's390x':
+        # s390x is slow
         return
 
     vmem0 = paramsurvey.utils.vmem()
